CoordinateMapper

Struct CoordinateMapper 

pub struct CoordinateMapper<'a> { /* private fields */ }
Stateless mapper that converts freely between three coordinate systems:

  1. Byte offset — absolute position in the UTF-8 buffer.
  2. Line / Col (LineCol) — 0-based line and byte-column.
  3. LSP position (LspPosition) — 0-based line and UTF-16 column.

All conversions go through a LineIndex that must be kept in sync with the buffer text (rebuild after each edit batch).

Implementations

Source

impl<'a> CoordinateMapper<'a>

pub fn new(index: &'a LineIndex) -> Self

Create a mapper backed by the given line index.

pub fn byte_to_line_col(&self, byte_offset: usize) -> Option<LineCol>

Byte offset -> LineCol.

pub fn line_col_to_byte(&self, lc: LineCol) -> Option<usize>

LineCol -> byte offset.

pub fn byte_to_lsp(&self, byte_offset: usize) -> Option<LspPosition>

Byte offset -> LspPosition.

pub fn lsp_to_byte(&self, pos: LspPosition) -> Option<usize>

LspPosition -> byte offset.

pub fn line_col_to_lsp(&self, lc: LineCol) -> Option<LspPosition>

LineCol -> LspPosition.

pub fn lsp_to_line_col(&self, pos: LspPosition) -> Option<LineCol>

LspPosition -> LineCol.