pub struct TextEdit {
pub range: Range<usize>,
pub new_text: String,
pub old_text: String,
}Expand description
A single atomic text edit expressed as a byte-range replacement.
Fields
range: Range<usize>Byte range in the document before this edit is applied.
new_text: StringThe text that replaces range.
old_text: StringThe text that was present in range before the edit (stored so we can
invert the operation for undo).
Implementations